==> primitive-0.1.11.tar.gz: primitive-0.1.11/src/primitive/lint/actions.py <==
from pathlib import Path
from primitive.utils.actions import BaseAction
import subprocess
from typing import Tuple
from loguru import logger
from ..utils.files import find_files_for_extension
from ..utils.verible import install_verible


class Lint(BaseAction):
    def execute(self, source: Path = Path.cwd()) -> Tuple[bool, str]:
        logger.debug("Starting linter...")
        files = find_files_for_extension(source, ".sv")
        if not files:
            message = "No files found to lint."
            logger.warning(message)
            return False, message

        logger.debug("Checking if verible is installed")
        try:
            subprocess.run(["verible-verilog-lint", "--version"], capture_output=True)
        except FileNotFoundError:
            logger.debug("Did not find verible. Installing...")
            try:
                system_info = self.primitive.hardware.get_system_info()
                install_verible(system_info=system_info)
            except Exception as exception:
                message = f"Failed to install verible. {exception}"
                logger.error(message)
                return False, message

        try:
            subprocess.run(["verible-verilog-lint", "--version"], capture_output=True)
        except FileNotFoundError:
            message = "Verible is not installed. Please install it to run lint."
            logger.error(message)
            return False, message

        # TODO:
        # run is great for now! we will need to switch to Popen if we want to stream the output
        logger.debug("Running linter...")
        result = subprocess.run(
            ["verible-verilog-lint", *files],
            capture_output=True,
            text=True,
        )

        logger.debug("Linting complete.")

        message = ""
        if self.primitive.DEBUG:
            if result.stderr:
                logger.error("\n" + result.stderr)
            if result.stdout:
                logger.info("\n" + result.stdout)
            message = "See above logs for linter output."
        else:
            message = result.stderr

        if result.returncode != 0:
            if not self.primitive.DEBUG:
                message = result.stderr
            return (False, message)
        else:
            message = "Linting successful."

        return True, message

==> primitive-0.1.14.tar.gz: primitive-0.1.14/src/primitive/lint/actions.py <==
from pathlib import Path
from primitive.utils.actions import BaseAction
import subprocess
from typing import Tuple
from loguru import logger
from ..utils.files import find_files_for_extension
from ..utils.verible import install_verible


class Lint(BaseAction):
    def execute(self, source: Path = Path.cwd()) -> Tuple[bool, str]:
        logger.debug("Starting linter for source: {source}")
        files = find_files_for_extension(source, ".sv")
        if not files:
            message = "No files found to lint."
            logger.warning(message)
            return False, message

        logger.debug("Checking if verible is installed")
        try:
            subprocess.run(["verible-verilog-lint", "--version"], capture_output=True)
        except FileNotFoundError:
            logger.debug("Did not find verible. Installing...")
            try:
                system_info = self.primitive.hardware.get_system_info()
                install_verible(system_info=system_info)
            except Exception as exception:
                message = f"Failed to install verible. {exception}"
                logger.error(message)
                return False, message

        try:
            subprocess.run(["verible-verilog-lint", "--version"], capture_output=True)
        except FileNotFoundError:
            message = "Verible is not installed. Please install it to run lint."
            logger.error(message)
            return False, message

        # TODO:
        # run is great for now! we will need to switch to Popen if we want to stream the output
        logger.debug("Running linter...")
        result = subprocess.run(
            ["verible-verilog-lint", *files],
            capture_output=True,
            text=True,
        )

        logger.debug("Linting complete.")

        message = ""
        if result.stderr:
            logger.error("\n" + result.stderr)
        if result.stdout:
            logger.info("\n" + result.stdout)
        message = "See above logs for linter output."

        if result.returncode != 0:
            if not self.primitive.DEBUG:
                message = result.stderr
            return (False, message)
        else:
            message = "Linting successful."

        return True, message
